;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "helix" "20251011.1609"
  "A minor mode emulating Helix keybindings."
  '((emacs "29.1"))
  :url "https://github.com/mgmarlow/helix-mode"
  :commit "f431fe6c1def0d679f3bae987d43025f13892dba"
  :revdesc "f431fe6c1def"
  :keywords '("convenience"))
